-- Copyright 2023 Lennart Augustsson
-- See LICENSE file for full license.
module Data.Bool_Type(module Data.Bool_Type) where
import qualified Prelude()              -- do not import Prelude
data Bool = False | True
  deriving ()  -- avoid deriving Typeable

